<?php

namespace EventPortal\Exceptions;

use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Illuminate\Support\Facades\App;
use Inertia\Inertia;
use Symfony\Component\HttpFoundation\Response;

class Handler extends ExceptionHandler
{
    /**
     * bound render method. overrides default handler call
     *
     * @param Request $request
     * @param \Exception $exception
     * @throws Throwable
     * @throws InvalidArgumentException
     * @phpcs:disable SlevomatCodingStandard.TypeHints.ParameterTypeHint.MissingNativeTypeHint
     */
    public function render($request, \Throwable $exception): Response
    {
        $response = parent::render($request, $exception);

        if ($this->shouldRenderErrorScreen($response)) {
            return Inertia::render('Error', config("errors.{$response->getStatusCode()}"))
                ->toResponse($request)
                ->setStatusCode($response->getStatusCode());
        }

        return $response;
    }

    public function report(\Throwable $exception): void
    {
        if (app()->bound('sentry') && $this->shouldReport($exception)) {
            app('sentry')->captureException($exception);
        }

        parent::report($exception);
    }

    private function shouldRenderErrorScreen(Response $response): bool
    {
        return App::environment('production') &&
            in_array(
                $response->getStatusCode(),
                array_keys(config('errors'))
            );
    }
}
